@@ -88,7 +88,7 @@ pub fn init(matches: &clap::ArgMatches) -> BetterResult<Config> {
                     )
                 })?;
             }
-            "ATOMIC_BASE_URL" => {
+            "ATOMIC_DOMAIN" => {
                 // Perhaps this should have some regex check
                 domain = value;
             }
@@ -125,7 +125,7 @@ pub fn init(matches: &clap::ArgMatches) -> BetterResult<Config> {
 
     let schema = if https { "https" } else { "http" };
     // I'm not convinced that this is the best way to do this.
-    let local_base_url = if https && port == 443 || !https && port == 80 {
+    let local_base_url = if https && port_https == 443 || !https && port == 80 {
         format!("{}://{}", schema, domain)
     } else {
         format!("{}://{}:{}", schema, domain, port)
